RKitFailure<T> class final

The operation failed. Stale data is preserved when a local cache existed.

The terminal failure state. The stream closes after this emission.

Inheritance

Constructors

RKitFailure(Object error, {T? data})
const

Properties

data → T?
The last known cached data, if available before the failure occurred.
final
error Object
The error that caused the failure.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited