data property
T?
data
final
The last known cached data, if available before the failure occurred.
Implementation
final T? data;
The last known cached data, if available before the failure occurred.
final T? data;