RKitFailure<T> class
final
The operation failed. Stale data is preserved when a local cache existed.
The terminal failure state. The stream closes after this emission.
Constructors
- RKitFailure(Object error, {T? data})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited